@@ -54,6 +54,7 @@ CardArea::CardArea()
   images.resize(40);
 
   SetCanFocus(true);
+  SetBackground(new Lum::OS::EmptyFill()); // TODO: Is this the best way?
 
   Observe(timerAction);
 }
@@ -411,7 +412,6 @@ void CardArea::Draw(int x, int y, size_t w, size_t h)
 
   Lum::OS::DrawInfo *draw=GetDrawInfo();
 
-  //DrawBackground(x,y,w,h);
   draw->PushForeground(backgroundColor);
   draw->FillRectangle(x,y,w,h);
   draw->PopForeground();
